summaryrefslogtreecommitdiffstats
path: root/src/H5Ipublic.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Ipublic.h')
-rw-r--r--src/H5Ipublic.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/H5Ipublic.h b/src/H5Ipublic.h
index c0ad6be..d699c92 100644
--- a/src/H5Ipublic.h
+++ b/src/H5Ipublic.h
@@ -76,13 +76,15 @@ typedef int64_t hid_t;
#define H5I_INVALID_HID (-1)
/**
* A function for freeing objects. This function will be called with an object
* ID type number and a pointer to the object. The function should free the
* object and return non-negative to indicate that the object
* can be removed from the ID type. If the function returns negative
* (failure) then the object will remain in the ID type.
*/
-typedef herr_t (*H5I_free_t)(void *, void **);
+typedef herr_t (*H5I_free_t)(void *obj, void **request);
/**
* The type of a function to compare objects & keys
@@ -76,13 +76,15 @@ typedef int64_t hid_t;
#define H5I_INVALID_HID (-1)
/**
- * A function for freeing objects. This function will be called with an object
- * ID type number and a pointer to the object. The function should free the
- * object and return non-negative to indicate that the object
- * can be removed from the ID type. If the function returns negative
- * (failure) then the object will remain in the ID type.
+ * A function for freeing objects. This function will be called with a pointer
+ * to the object and a pointer to a pointer to the asynchronous request object.
+ * The function should free the object and return non-negative to indicate that
+ * the object can be removed from the ID type. If the function returns negative
+ * (failure) then the object will remain in the ID type. For asynchronous
+ * operations and handling the request parameter, see the HDF5 user guide and
+ * VOL connector author guide.
*/